abclinuxu.cz AbcLinuxu.cz itbiz.cz ITBiz.cz HDmag.cz HDmag.cz abcprace.cz AbcPráce.cz
AbcLinuxu hledá autory!
Inzerujte na AbcPráce.cz od 950 Kč
Rozšířené hledání
×
    dnes 11:11 | Bezpečnostní upozornění

    V implementaci Broadcom 802.11 byla zjištěna chyba ve zpracování WPS/EAP, týká se to SDK od roku 2010. Broadcom podle výzkumníka Quentina Kaisera odmítl CVE přidělit. Modemy Huawei a Technicolor jsou používány i v ČR, v LTE routerech, běžných domácích routerech a firemních přístupových bodech, jejich současný počet a zranitelnost konkrétních verzí však zatím neznáme. Více detailů a demo. GitHub / Broadcom 802.11 SDK Detection Toolkit.

    vencour | Komentářů: 0
    dnes 05:11 | Nová verze

    Byla vydána nová verze 10.8 z Debianu vycházející linuxové distribuce DietPi pro (nejenom) jednodeskové počítače. Přehled novinek v poznámkách k vydání. Přibyl balíček DietPi WireGuard.

    Ladislav Hagara | Komentářů: 0
    včera 21:22 | Pozvánky

    Oslavte vydání openSUSE Leap 16.1 s námi v Praze! Ve středu 4. listopadu 2026 (den po vydání Leapu 16.1) vás zveme na malou oslavu vydání openSUSE Leap 16.1 do pražské kanceláře SUSE. Připravili jsme pro vás dvě krátké přednášky: … více »

    lkocman | Komentářů: 0
    včera 16:44 | Bezpečnostní upozornění

    Dle plánu bylo PHP vydáno v nových verzích 8.5.12, 8.4.27, 8.3.36 a 8.2.35. Opraveny jsou kritické zranitelnosti CVE-2026-109618 a CVE-2026-109619 aneb PHP2Shell.

    Ladislav Hagara | Komentářů: 8
    včera 11:55 | Nová verze

    UBports, nadace a komunita kolem Ubuntu pro telefony a tablety Ubuntu Touch, vydala Ubuntu Touch 24.04-2.1 a 24.04-1.5. S opravou kritických zranitelností.

    Ladislav Hagara | Komentářů: 0
    včera 11:33 | IT novinky

    Společnost Škoda Auto zveřejnila na Printables bezplatné 3D modely příslušenství do svých vozů (držáky na nápoje, pomůcky pro vedení kabelů, mincovníky, háčky na USB kabely a čepice pro kapsy na zadních stranách opěradel sedadel, držáky na telefony a úchyty pro horní upevnění bezpečnostních pásů).

    Ladislav Hagara | Komentářů: 9
    včera 05:11 | Zajímavý článek

    Nové číslo časopisu Raspberry Pi zdarma ke čtení: Raspberry Pi Official Magazine 170 (pdf).

    Ladislav Hagara | Komentářů: 0
    včera 04:33 | Bezpečnostní upozornění

    Dnes v 16:00 (14:00 UTC) budou opraveny 2 kritické zranitelnosti s CVSS 9.2 v PHP.

    Ladislav Hagara | Komentářů: 7
    včera 01:37 | Bezpečnostní upozornění

    Nizozemská policie 13. října 2026 zabavila v datacentru Amsterdam Science Park server italského poskytovatele internetových služeb Autistici/Inventati (A/I), a to na základě americké žádosti o mezinárodní právní pomoc.… více »

    vencour | Komentářů: 11
    20.10. 20:47 | Bezpečnostní upozornění
    Hlášeny RCE v NGINX. Náprava dostupná. … více »
    vencour | Komentářů: 0
    Které desktopové prostředí na Linuxu používáte?
     (9%)
     (7%)
     (4%)
     (21%)
     (30%)
     (9%)
     (5%)
     (2%)
     (14%)
     (20%)
    Celkem 2891 hlasů
     Komentářů: 33, poslední 20.10. 23:44
    Rozcestník

    Dotaz: Jak naučit USB IDE harddisk spát?

    23.12.2012 22:20 Jirka | skóre: 25
    Jak naučit USB IDE harddisk spát?
    Přečteno: 1155×
    Zdravím všechny, mám 2,5" IDE hadr v externím USB boxu, který je připojen k servříku a jede většinu času naprázdno, takže by bylo rozumné ten disk po pár minutách nečinnosti vypnout.
    lsusb -l vypíše
    Bus 001 Device 004: ID 058f:6391 Alcor Micro Corp. 
    Device Descriptor:
      bLength                18
      bDescriptorType         1
      bcdUSB               2.00
      bDeviceClass            0 (Defined at Interface level)
      bDeviceSubClass         0 
      bDeviceProtocol         0 
      bMaxPacketSize0        64
      idVendor           0x058f Alcor Micro Corp.
      idProduct          0x6391 
      bcdDevice            1.00
      iManufacturer           1 Generic
      iProduct                2 USB TO IDE Bridge
      iSerial                 0 
      bNumConfigurations      1
      Configuration Descriptor:
        bLength                 9
        bDescriptorType         2
        wTotalLength           32
        bNumInterfaces          1
        bConfigurationValue     1
        iConfiguration          0 
        bmAttributes         0xc0
          Self Powered
        MaxPower              100mA
        Interface Descriptor:
          bLength                 9
          bDescriptorType         4
          bInterfaceNumber        0
          bAlternateSetting       0
          bNumEndpoints           2
          bInterfaceClass         8 Mass Storage
          bInterfaceSubClass      6 SCSI
          bInterfaceProtocol     80 Bulk-Only
          iInterface              0 
          Endpoint Descriptor:
            bLength                 7
            bDescriptorType         5
            bEndpointAddress     0x01  EP 1 OUT
            bmAttributes            2
              Transfer Type            Bulk
              Synch Type               None
              Usage Type               Data
            wMaxPacketSize     0x0200  1x 512 bytes
            bInterval               0
          Endpoint Descriptor:
            bLength                 7
            bDescriptorType         5
            bEndpointAddress     0x82  EP 2 IN
            bmAttributes            2
              Transfer Type            Bulk
              Synch Type               None
              Usage Type               Data
            wMaxPacketSize     0x0200  1x 512 bytes
            bInterval               0
    Device Qualifier (for other device speed):
      bLength                10
      bDescriptorType         6
      bcdUSB               2.00
      bDeviceClass            0 (Defined at Interface level)
      bDeviceSubClass         0 
      bDeviceProtocol         0 
      bMaxPacketSize0        64
      bNumConfigurations      1
    Device Status:     0x0000
      (Bus Powered)
    

    Příkaz "hdparm -S 60 /dev/sda" odpoví:
    /dev/sda:
     setting standby to 60 (5 minutes)
    SG_IO: bad/missing sense data, sb[]:  f0 00 05 00 00 00 00 0a 00 00 00 00 20 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00
    
    a nic se nestane. Neví někdo, co s tím?
    Díky.
    Dokud to funguje, nešťourej se v tom!...

    Odpovědi

    26.12.2012 18:42 Martin K.
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Pro uspávání USB a vůbec všeho včetně komponent RAIDu celkem úspěšně používám http://code.google.com/p/spindown/wiki/Usage
    Josef Kufner avatar 27.12.2012 11:54 Josef Kufner | skóre: 70
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Koukni na nástroj hdparm:
    hdparm - get/set hard disk parameters - version v9.43, by Mark Lord.
    
    Usage:  hdparm  [options] [device ...]
    
    Options:
     -C   Check drive power mode status
     -M   Get/set acoustic management (0-254, 128: quiet, 254: fast)
     -S   Set standby (spindown) timeout
     -y   Put drive in standby mode
     -Y   Put drive to sleep
    ...
    
    Po rebootu/připojení disku je potřeba to nastavit znovu, takže si udělej pravidlo pro udev.
    Hello world ! Segmentation fault (core dumped)
    29.12.2012 12:22 Petr Šobáň | skóre: 80 | blog: soban | Olomouc
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Jsou pouze dvě možnosti.

    Buď to neprojde přes ten USB převodník.

    A nebo HDD nepodporuje všechny možnosti.

    Skus vyskoušet jiný parametr za -S 241 třeba.

    Ale spíš to vypadá podle chyby že je to proto že to neprojde přes to USB.
    29.12.2012 13:43 Jirka | skóre: 25
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Dělá to ten převodník, otázka, co se s tím dá dělat.
    I s chybou jsem to schopnej dostat do režimu standby, ale hadrdisk evidentně pořád běží.
    Dokud to funguje, nešťourej se v tom!...
    29.12.2012 14:01 Petr Šobáň | skóre: 80 | blog: soban | Olomouc
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Jedině vyměnit ten USB převodník za jiný typ.

    Projde přes ten tvůj SMART?

    Přes který projde smart je možné že projde i příkaz k uspání.
    29.12.2012 23:59 Jirka | skóre: 25
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    tak neprojde, ale ani ten disk není v úplně 100% kondici, jak se ukázalo.Teď z něj pracně doluju data, co jsem na něj přesunul :-D
    Ale díky za snahu, vyřeším to něčím novějším.
    Dokud to funguje, nešťourej se v tom!...
    30.12.2012 09:43 Petr Šobáň | skóre: 80 | blog: soban | Olomouc
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Novější neznamená že bude podpora v linuxu :-)

    Mám starý box na PATA HDD a přes ten SMART projde, a nový box co jsem koupil taky pro starý PATA disk co jsem vytáhl z PC přes ten SMART neprojde - nepodporovaný řadič :-)

    Samozřejmě oba řadiče fungují (zápis-čtení z HDD).
    30.12.2012 12:28 Jirka | skóre: 25
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    sériový řadiče s tím, předpokládám, problémy nemaj.
    Dokud to funguje, nešťourej se v tom!...
    30.12.2012 22:19 Petr Šobáň | skóre: 80 | blog: soban | Olomouc
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Nejsem si jistej - záleží na čipu v tom usb rámečku.

    Já žádný nemám, sata disky mám v PC.
    2.1.2013 08:43 Trubicoid2
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Naopak, vetsina usb2>sata smart nepropusti. E-sata je bez problemu a videl jsem zatim jen jeden usb3>sata disk a tam smart prochazel, ale nejak divne. Tedy po restartu smartctl -a neukazoval hotovy testy, takze to je jen nejaka emulace nebo co?

    Jinak na uspavani se da pouzit sdparm misto hdparm, ale velmi zalezi, jak je radic implementovan.
    2.1.2013 19:01 Zaphod | skóre: 37 | blog: zaphod_blog
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Niektoré usb2->sata prepustia smart príkazom

    smartctl -a -d sat

    Prepínačom "-d TYPE" sa dá zvoliť typ radiča. Možné hodnoty sú v man smartctl.
    3.1.2013 10:13 frr | skóre: 34
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    Aby to fungovalo přímo na ATA nebo SCSI vrstvě, tak je potřeba, aby ten převodník uměl ATA nebo SCSI passthrough (SAT nebo UAS). Tohle bych hledal spíš u SATA než ATA bridgů na USB.

    http://sourceforge.net/apps/trac/smartmontools/wiki/USB

    http://en.wikipedia.org/wiki/USB_Attached_SCSI

    http://www.krup.cz/print.asp?cls=stoitem&stiid=3581

    ATA over USB uměly jako první snad některé převodníky Cypress, v Linuxu je proto už dlouho podpora.

    Některé značkové USB rámečky měly od výrobce utilitu, kterou se dal nastavit timeout pro uspání disku (proprietární řešení).
    [:wq]
    3.1.2013 21:59 Loso | skóre: 11
    Rozbalit Rozbalit vše Re: Jak naučit USB IDE harddisk spát?
    ahoj,

    mam usb disk-y, ktore uspesne uspavam pomocou
    sdparm $DISK -C sync
    sdparm $DISK -C stop
    
    problem bol na zaciatku v tom, ze ihned po uspani sa vygeneroval event, ktory ich znova roztocil... (ergo cvakol a tocil dalej), bolo treba custom udev rule, ktory tento jav potlacal, pre inspiraciu (moj pracoval podla vendor)
    /etc/udev/rules.d/60-persistent-storage.rules:KERNEL!="sr*", ATTRS{vendor}!="ST350083", IMPORT{program}="/sbin/blkid -o udev -p $tempnode"

    Vela zdaru, Loso

    Založit nové vlákno • Nahoru

    Tiskni Sdílej: Linkuj Jaggni to Vybrali.sme.sk Google Del.icio.us Facebook

    ISSN 1214-1267   www.czech-server.cz
    © 1999-2015 Nitemedia s. r. o. Všechna práva vyhrazena.